@@ -24,7 +24,7 @@ public class C_TextMatchSQLRegexp extends C_Expression {
 		this.leftArgument = leftArgument;
 		this.rightArgument = rightArgument;
 		if (leftArgument != null && rightArgument != null) {
-			this.readableExpression = "TextMatchSQLRegexp("
+			this.readableExpression = "Match("
 					+ leftArgument.getReadableExpression() + ","
 					+ rightArgument.getReadableExpression() + ")";
 		}
